@@ -43,3 +43,16 @@ test_that("select_loc() accepts name spec", {
     c(foo_1 = 1L, foo_2 = 2L)
   )
 })
+
+test_that("result is named even with constant inputs (#173)", {
+  expect_identical(
+    eval_select("Sepal.Width", iris),
+    c(Sepal.Width = 2L)
+  )
+})
+
+test_that("can forbid rename syntax (#178)", {
+  expect_error(select_loc(mtcars, c(foo = cyl), allow_rename = FALSE), "Can't rename")
+  expect_error(select_loc(mtcars, c(cyl, foo = cyl), allow_rename = FALSE), "Can't rename")
+  expect_named(select_loc(mtcars, starts_with("c") | all_of("am"), allow_rename = FALSE), NULL)
+})
